<?php

namespace Litecms\Parser\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Parser\Models\Parser;


class ParserAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Parser $parser, array $request = [])
    {
        $this->model = $parser;

        $function = Str::camel($action);
        event('litecms.parser.parser.action.' . $action . 'ing', [$parser]);
        $data =  $this->$function($parser, $request);
        event('litecms.parser.parser.action.' . $action . 'ed', [$parser]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Parser $parser, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $parser = $parser->create($attributes);
        return $parser;
    }

    public function update(Parser $parser, array $request)
    {
        $attributes = $request;
        $parser->update($attributes);
        return $parser;
    }

    public function delete(Parser $parser, array $request)
    {
        $parser->delete();
        return $parser;
    }

    public function copy(Parser $parser, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $parser = $parser->replicate();
            $parser->created_at = Carbon::now();
            $parser->save();
            return $parser;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $parser->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $parser;
    }


}
