<?php

namespace Litecms\Parser\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Parser\Models\Whatsapp;


class WhatsappAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Whatsapp $whatsapp, array $request = [])
    {
        $this->model = $whatsapp;

        $function = Str::camel($action);
        event('litecms.parser.whatsapp.action.' . $action . 'ing', [$whatsapp]);
        $data =  $this->$function($whatsapp, $request);
        event('litecms.parser.whatsapp.action.' . $action . 'ed', [$whatsapp]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(Whatsapp $whatsapp, array $request)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $whatsapp = $whatsapp->create($attributes);
        return $whatsapp;
    }

    public function update(Whatsapp $whatsapp, array $request)
    {
        $attributes = $request;
        $whatsapp->update($attributes);
        return $whatsapp;
    }

    public function delete(Whatsapp $whatsapp, array $request)
    {
        $whatsapp->delete();
        return $whatsapp;
    }

    public function copy(Whatsapp $whatsapp, array $request)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $whatsapp = $whatsapp->replicate();
            $whatsapp->created_at = Carbon::now();
            $whatsapp->save();
            return $whatsapp;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $whatsapp->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $whatsapp;
    }


}
