<?php

namespace Litecms\Parser\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Parser\Actions\ParserAction;
use Litecms\Parser\Http\Requests\ParserActionRequest;
use Litecms\Parser\Http\Resources\ParserResource;
use Litecms\Parser\Models\Parser;

/**
 * Admin web controller class.
 */
class ParserActionController extends BaseController
{

    /**
     * Action controller function for parser.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ParserActionRequest $request, Parser $parser, $action)
    {
        try {
            $parser = ParserAction::run($request, $parser, $action);

            $data = new ParserResource($parser);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('parser::parser.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('parser/parser/' . $parser->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('parser/parser/' . $parser->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
