<?php

namespace Litecms\Parser\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Parser\Http\Requests\ParserActionsRequest;
use Litecms\Parser\Models\ParserActions;

/**
 * Admin web controller class.
 */
class ParserActionsController extends BaseController
{

    /**
     * Action controller function for parser.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ParserActionsRequest $request, $action)
    {
        try {
            $parser = ParserActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('parser::parser.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('parser/parser/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('parser/parser/' . $action))
                ->redirect();
        }
    }
}
