<?php

namespace Litecms\Parser\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Parser\Http\Resources\ParserResource;
use Litecms\Parser\Http\Resources\ParsersCollection;
use Litecms\Parser\Scopes\ParserPublicScope;
use Litecms\Parser\Models\Parser;

class ParserPublicController extends BaseController
{

    /**
     * Show parser's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Parser::pushScope(new RequestScope())
            ->pushScope(new ParserPublicScope())
            ->select('parsers.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new ParsersCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('parser::parser.names'))
            ->view('parser::public.parser.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show parser.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Parser::findBySlug($slug);
        $data = new ParserResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('parser::parser.name'))
            ->view('parser::public.parser.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
