<?php

namespace Litecms\Parser\Http\Controllers;

use Exception;
use Litecms\Parser\Actions\ParserWorkflow;
use Litecms\Parser\Http\Requests\ParserWorkflowRequest;
use Litecms\Parser\Http\Resources\ParserResource;
use Litecms\Parser\Models\Parser;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class ParserWorkflowController extends BaseController
{
    /**
     * Action controller function for parser.
     *
     * @param Model $parser
     * @param action next action for the parser.
     *
     * @return Response
     */
    public function __invoke(ParserWorkflowRequest $request, Parser $parser, $trasition)
    {
        try {
            $parser = ParserWorkflow::run($request, $parser, $trasition);
            $data = new ParserResource($parser);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('parser::parser.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('parser/parser/' . $parser->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('parser/parser/' . $parser->getRouteKey()))
                ->redirect();
        }
    }
}
