<?php

namespace Litecms\Parser\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Parser\Actions\WhatsappAction;
use Litecms\Parser\Http\Requests\WhatsappActionRequest;
use Litecms\Parser\Http\Resources\WhatsappResource;
use Litecms\Parser\Models\Whatsapp;

/**
 * Admin web controller class.
 */
class WhatsappActionController extends BaseController
{

    /**
     * Action controller function for whatsapp.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(WhatsappActionRequest $request, Whatsapp $whatsapp, $action)
    {
        try {
            $whatsapp = WhatsappAction::run($request, $whatsapp, $action);

            $data = new WhatsappResource($whatsapp);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('parser::whatsapp.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('parser/whatsapp/' . $whatsapp->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('parser/whatsapp/' . $whatsapp->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
