<?php

namespace Litecms\Parser\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Parser\Http\Resources\ParserResource;
use Litecms\Parser\Http\Resources\ParsersCollection;
use Litecms\Parser\Scopes\WhatsappPublicScope;
use Litecms\Parser\Models\Whatsapp;

class WhatsappPublicController extends BaseController
{

    /**
     * Show whatsapp's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Whatsapp::pushScope(new RequestScope())
            ->pushScope(new WhatsappPublicScope())
            ->select('whatsapps.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new WhatsappsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('parser::whatsapp.names'))
            ->view('parser::public.whatsapp.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show whatsapp.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Whatsapp::findBySlug($slug);
        $data = new WhatsappResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('parser::whatsapp.name'))
            ->view('parser::public.whatsapp.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
