<?php

namespace Litecms\Parser\Http\Controllers;

use Exception;
use Litecms\Parser\Actions\WhatsappWorkflow;
use Litecms\Parser\Http\Requests\WhatsappWorkflowRequest;
use Litecms\Parser\Http\Resources\WhatsappResource;
use Litecms\Parser\Models\Whatsapp;
use Litepie\Http\Controllers\ActionController as BaseController;

/**
 * Workflow controller class.
 *
 */
class WhatsappWorkflowController extends BaseController
{
    /**
     * Action controller function for whatsapp.
     *
     * @param Model $whatsapp
     * @param action next action for the whatsapp.
     *
     * @return Response
     */
    public function __invoke(WhatsappWorkflowRequest $request, Whatsapp $whatsapp, $trasition)
    {
        try {
            $whatsapp = WhatsappWorkflow::run($request, $whatsapp, $trasition);
            $data = new WhatsappResource($whatsapp);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('parser::whatsapp.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('parser/whatsapp/' . $whatsapp->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('parser/whatsapp/' . $whatsapp->getRouteKey()))
                ->redirect();
        }
    }
}
