<?php

namespace Litecms\Parser\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Parser\Events\ParserAction as ParserActionEvent;
use Litecms\Parser\Notifications\ParserAction as ParserActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ParserAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ParserActionEvent.
     *
     * @param   ParserActionEvent  $event
     * @return mixed
     */
    public function handle(ParserActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $parser.
     *
     * @param   ParserActionEvent  $event
     * @return void
     */
    public function create(ParserActionEvent $event)
    {
        $client = $event->$parser->client;
        Notification::send($client, new ParserActionNotification($event));
    }

    /**
     * Handle the ParserActionEvent as a listener.
     *
     * @param   ParserActionEvent  $event
     * @return mixed
     */
    public function asListener(ParserActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ParserActionEvent  $event
     * @return bool
     */
    private function isAllowed(ParserActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
