<?php

namespace Litecms\Parser\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Parser\Events\ParserWorkflow as ParserWorkflowEvent;
use Litecms\Parser\Notifications\ParserWorkflow as ParserWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ParserWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ParserWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $parser is submitted.
     *
     * @param ParserWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ParserWorkflowEvent $event)
    {
        $client = $event->$parser->client;
        Notification::send($client, new ParserWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $parser is published.
     *
     * @param ParserWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ParserWorkflowEvent $event)
    {
        $client = $event->$parser->client;
        Notification::send($client, new ParserWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $parser is approved.
     *
     * @param ParserWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ParserWorkflowEvent $event)
    {
        $client = $event->$parser->client;
        Notification::send($client, new ParserWorkflowNotification($event));
    }

    /**
     * Handles the $parser workflow event as a listener.
     *
     * @param ParserWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ParserWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
