<?php

namespace Litecms\Parser\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Parser\Events\WhatsappAction as WhatsappActionEvent;
use Litecms\Parser\Notifications\WhatsappAction as WhatsappActionNotification;
use Litepie\Actions\Concerns\AsAction;

class WhatsappAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the WhatsappActionEvent.
     *
     * @param   WhatsappActionEvent  $event
     * @return mixed
     */
    public function handle(WhatsappActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $whatsapp.
     *
     * @param   WhatsappActionEvent  $event
     * @return void
     */
    public function create(WhatsappActionEvent $event)
    {
        $client = $event->$whatsapp->client;
        Notification::send($client, new WhatsappActionNotification($event));
    }

    /**
     * Handle the WhatsappActionEvent as a listener.
     *
     * @param   WhatsappActionEvent  $event
     * @return mixed
     */
    public function asListener(WhatsappActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   WhatsappActionEvent  $event
     * @return bool
     */
    private function isAllowed(WhatsappActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
