<?php

namespace Litecms\Parser\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Parser\Events\WhatsappWorkflow as WhatsappWorkflowEvent;
use Litecms\Parser\Notifications\WhatsappWorkflow as WhatsappWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class WhatsappWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(WhatsappWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $whatsapp is submitted.
     *
     * @param WhatsappWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(WhatsappWorkflowEvent $event)
    {
        $client = $event->$whatsapp->client;
        Notification::send($client, new WhatsappWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $whatsapp is published.
     *
     * @param WhatsappWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(WhatsappWorkflowEvent $event)
    {
        $client = $event->$whatsapp->client;
        Notification::send($client, new WhatsappWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $whatsapp is approved.
     *
     * @param WhatsappWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(WhatsappWorkflowEvent $event)
    {
        $client = $event->$whatsapp->client;
        Notification::send($client, new WhatsappWorkflowNotification($event));
    }

    /**
     * Handles the $whatsapp workflow event as a listener.
     *
     * @param WhatsappWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(WhatsappWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
