<?php
namespace Litecms\Parser\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Parser\Events\ParserAction as ParserActionEvent;
use Litecms\Parser\Models\Parser;

class ParserAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $parser;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param ParserActionEvent $parser
     * @param string $action
     */
    public function __construct(ParserActionEvent $parser, string $action)
    {
        $this->action = $action;
        $this->parser = $parser;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Parser Approved - ' . config('app.name'))
            ->view('parser::parser.email.action', ['data' => $this->parser]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
