<?php
namespace Litecms\Parser\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Parser\Events\WhatsappAction as WhatsappActionEvent;
use Litecms\Parser\Models\Whatsapp;

class WhatsappAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $whatsapp;

    protected $action;

    /**
     * Create a new notification instance.
     *
     * @param WhatsappActionEvent $whatsapp
     * @param string $action
     */
    public function __construct(WhatsappActionEvent $whatsapp, string $action)
    {
        $this->action = $action;
        $this->whatsapp = $whatsapp;
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Whatsapp Approved - ' . config('app.name'))
            ->view('parser::whatsapp.email.action', ['data' => $this->whatsapp]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
