<?php

namespace Litecms\Parser\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Parser\Models\Parser;

class ParserPolicy
{

    use ParserAction;
    use ParserWorkflow;

    /**
     * Determine if the given user can view the parser.
     *
     * @param UserPolicyInterface $authUser
     * @param Parser $parser
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Parser $parser)
    {
        if ($authUser->canDo('parser.parser.view') && $authUser->isAdmin()) {
            return true;
        }

        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can create a parser.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('parser.parser.create');
    }

    /**
     * Determine if the given user can update the given parser.
     *
     * @param UserPolicyInterface $authUser
     * @param Parser $parser
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Parser $parser)
    {
        if ($authUser->canDo('parser.parser.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given parser.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Parser $parser)
    {
        return $parser->user_id == user_id() && $parser->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given parser.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Parser $parser)
    {
        if ($authUser->canDo('parser.parser.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given parser.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Parser $parser)
    {
        if ($authUser->canDo('parser.parser.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
