<?php

namespace Litecms\Parser\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Parser\Models\Whatsapp;

class WhatsappPolicy
{

    use WhatsappAction;
    use WhatsappWorkflow;

    /**
     * Determine if the given user can view the whatsapp.
     *
     * @param UserPolicyInterface $authUser
     * @param Whatsapp $whatsapp
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Whatsapp $whatsapp)
    {
        if ($authUser->canDo('parser.whatsapp.view') && $authUser->isAdmin()) {
            return true;
        }

        return $whatsapp->user_id == user_id() && $whatsapp->user_type == user_type();
    }

    /**
     * Determine if the given user can create a whatsapp.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('parser.whatsapp.create');
    }

    /**
     * Determine if the given user can update the given whatsapp.
     *
     * @param UserPolicyInterface $authUser
     * @param Whatsapp $whatsapp
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Whatsapp $whatsapp)
    {
        if ($authUser->canDo('parser.whatsapp.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $whatsapp->user_id == user_id() && $whatsapp->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given whatsapp.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Whatsapp $whatsapp)
    {
        return $whatsapp->user_id == user_id() && $whatsapp->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given whatsapp.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Whatsapp $whatsapp)
    {
        if ($authUser->canDo('parser.whatsapp.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given whatsapp.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Whatsapp $whatsapp)
    {
        if ($authUser->canDo('parser.whatsapp.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
