<?php

namespace Litecms\Parser\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Parser\Parsers;

class ParserServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'parser');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'parser');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Litecms\Parser\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Parser\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Parser\Providers\ActionServiceProvider::class);
        $this->app->register(\Litecms\Parser\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.parser', function($app)
        {
            return $this->app->make(Parsers::class);
        });
    }

    /**
     * Merges user's and parser's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.parser'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/parser.php', 'litecms.parser.parser'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/whatsapp.php', 'litecms.parser.whatsapp'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.parser'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/parser')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/parser')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/parser')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
